@@ -2,15 +2,15 @@ package Net::SSLLabs;
 
 use strict;
 use warnings;
-use LWP::UserAgent();
 use JSON();
+use URI::Escape();
+use LWP::UserAgent();
 use Net::SSLLabs::Info();
 use Net::SSLLabs::Host();
 use Net::SSLLabs::Endpoint();
 use Net::SSLLabs::StatusCodes();
-use URI::Escape();
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new {
     my ($class) = @_;
@@ -78,11 +78,11 @@ sub _sort_ssllabs_params {
     }
     elsif ( $b eq 'host' ) {
         return 1;
-    } elsif ( $a eq 's' ) {
+    }
+    elsif ( $a eq 's' ) {
         return -1;
-    } elsif ( $b eq 's' ) {
-        return 1;
-    }else {
+    }
+    else {
         return $a cmp $b;
     }
 }
@@ -125,11 +125,11 @@ __END__
 
 =head1 NAME
 
-Net::SSLLabs - An interface to the ssllabs.com service
+Net::SSLLabs - Analyze the configuration of any SSL web server on the public Internet via ssllabs.com
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -148,7 +148,8 @@ Check the security of your TLS services
 
 =head1 DESCRIPTION
 
-Net::SSLLabs provides a full interface to the API provided by L<https://www.ssllabs.com/ssltest>.
+This is a client module for the L<https://www.ssllabs.com/ssltest> API, which provides a deep analysis
+of the configuration of any SSL/TLS web server on the public Internet
 
 =head1 SUBROUTINES/METHODS
 
