@@ -9,7 +9,7 @@ use Net::SSLLabs::Protocol();
 use Net::SSLLabs::Chain();
 use Net::SSLLabs::Key();
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -215,7 +215,11 @@ sub has_sct {
 
 sub dh_primes {
     my ($self) = @_;
-    return @{ $self->{dhPrimes} };
+    if (defined $self->{dhPrimes}) {
+	    return @{$self->{dhPrimes}};
+    } else {
+	    return ();
+    }
 }
 
 sub dh_uses_known_primes {
@@ -242,7 +246,7 @@ Net::SSLLabs::EndpointDetails - EndpointDetails object
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SUBROUTINES/METHODS
 
